<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;


jimport('joomla.user.helper');
jimport('joomla.access.access');



/**
 * Helper for mod_articles_latest
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 * @since       1.6.0
 */
abstract class easyblog_posts
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList(&$params)
	{
		
		
		$engine = JPATH_ADMINISTRATOR . '/components/com_easyblog/includes/easyblog.php';
		
		if (!JFile::exists($engine)) {
		    return;
		}
		
		include_once($engine);
		
		$config = EB::config();
		
		// Content Source
		$source = $params->get('easyblog_content_type', 'categories');
		
		// Featured
		$show_featured = $params->get('easyblog_featured', '');
		
		
		// Archived
		$show_archived = $params->get('easyblog_archived', '0');
		
		
		// Ordering
		$ordering = $params->get('easyblog_ordering', 'title DESC');	
		
		// Item count
		$count = $params->get('easyblog_count', '5');
		$offset = $params->get('easyblog_offset', '0');
		
		// Link Type
		$link_type = $params->get('easyblog_link_type', 'item');
		$link_fallback = $params->get('easyblog_link_fallback');
		
		// Define DB
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		
		// Set current time to see if items should be published
		$nullDate	= $db->getNullDate();
		$date = JFactory::getDate();
		$now = $date->toSql();
		
		// Get the layout item settings
		// We need this to get some of the values for related items.
		
		$settings = json_decode($params->get('layout_settings'));
		
		$strict_readmore = 0;
		
		$placeholder = 0;
		$placeholder_path = "";
		
		$fulltext_placeholder = 0;
		$fulltext_placeholder_path = "";
		
		
		// Some things that require extra database calls so lets check if we need them anyway
		$get_tags = 0;
		$get_ratings = 0;
		$get_comments = 0;
		
		foreach($settings as $key=>$colcontent) {
		
			
			foreach ($colcontent as $name =>$item_content) {
			
			
				if($name == 'readmore') {
		    		if(isset($item_content->strict_readmore)) {
		    			$strict_readmore = $item_content->strict_readmore;
		    		}
		    	}
		    	
		    	if($name == 'image') {
		    		if(isset($item_content->placeholder)) {
		    			$placeholder = $item_content->placeholder;
		    			$placeholder_path = $item_content->placeholder_path;	
		    		}
		    	}
		    	
		    	if($name = "tagblock") {
		    		$get_tags = 1;
		    	}
		    	
		    	if($name = "ratings") {
		    		$get_ratings = 1;
		    	}
		    	
		    	if($name = "comments") {
		    		$get_comments = 1;
		    	}		    	
		    }
		}
		
		
		
		// Access filter
		$access     = !JComponentHelper::getParams('com_easyblog')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		
		
		// Get view access levels for current user id
		$user = JFactory::getUser();
		$viewLevels = JAccess::getAuthorisedViewLevels(JUserHelper::getUserId($user->username));
		$access_levels = implode(",", $viewLevels);	
		
		if($source=='categories') {
			$cats = json_decode($params->get('easyblog_content_categories_limit', ''));
		
			// Cast object to an array
			$catitems = (array)$cats;
			
			// Get catids from array
			$catids = array_keys($catitems);
			
			// Count number of cats to process
			$limitcount = count($catitems);
			
			
		
				// If just a single value then proceed as usual
					if($limitcount <= 1) {
				
						// If no limits on category numbers we just perform the standard query
						$query->select('*');
						$query->from('#__easyblog_post'); 
						
						if(!empty($catids)) {
							$query->where('category_id = ' . implode(',', $catids));
						}
						
						$query->where('(publish_down = '.$db->Quote($nullDate).' OR publish_down >= '.$db->Quote($now).')')
								->where('publish_up <= '.$db->Quote($now))
								->where('published = 1');
					
						// Featured
						if($show_featured == 0) {
							$query->where('featured = 0');
						} elseif($show_featured == 1) {
							$query->where('featured = 1');
						} 
						
						
						if($show_archived == 0) {
								$query->where('state = 0');
						} elseif($show_archived == 1) {
								$query->where('state = 2');
						} elseif($show_archived == 2) {
								$query->where('state in (0,2)');
						}
						
						
						if(isset($catids[0])) {
							$limit = $cats->{$catids[0]};
							
							if($limit > $count || $limit == "") {
								$limit = $count;
							}
							
						} else {
							$limit = $count;
						}
						
						// Set the limit for the items as a whole		    			    
						$query->order($ordering);
						$query->setLimit($limit, $offset);
						$db->setQuery($query, 0);
						$items = $db->loadObjectList();
						
					} else {
					
						// Get specific items
					//	$cats = $params->get('joomla_content_items', '');
					
					
					
					// Loops through the catd ids and limits set
					// catid:limit
					// 42:2
				
					// We need to calculate the new total items to display
					// Check later to see if it's higher or lower than the count amount
					$total = '';
					
				
					foreach ($cats as $catid => $limit) {
						
						
						// If limit is left blank in the settings
						if($limit == "") {
							$limit = $count;
						}
						
						
						// Set up the union query
						${'q'.$catid} = $db->getQuery(true);
					
						// Create the select for each cat
						${'q'.$catid}
						    ->select('*')
						    ->from('#__easyblog_post')
						    ->where('category_id = '.$catid.'')
						    ->where('published = 1')
						    ->where('(publish_down = '.$db->Quote($nullDate).' OR publish_down >= '.$db->Quote($now).')')
						    ->where('publish_up <= '.$db->Quote($now))
						    ->order(''.$ordering.'');
						 
						 	// Featured items
						    if($show_featured == 0) {
						    	${'q'.$catid}->where('featured = 0');
						    } elseif($show_featured == 1) {
						    	${'q'.$catid}->where('featured = 1');
						    } 
						    
						    if($show_archived == 0) {
						    	${'q'.$catid}->where('state = 0');
						    } elseif($show_archived == 1) {
						    	${'q'.$catid}->where('state = 2');
						    } elseif($show_archived == 2) {
						    	${'q'.$catid}->where('state in (0,2)');
						    }
						    
						    // Limit the items from this category
						    ${'q'.$catid}->setLimit($limit,$offset);
						    
						    $total += $limit;
					}
							
					// Perform the base query
					// First item is a dummy
					// Then loop through the unions
					// created int he previous step
					
					$query
					    ->select('*')
					    ->from('#__content')
					    ->where('1 = 0');
					    
					 foreach ($cats as $catid => $limit) {
					   	$query->union(${'q'.$catid});
					 }
					 
					 
					// Add the order by option
					// A bug in Joomla currently means that we have to
					// Set this manually
				   
				    
				    // Set the limit for the items as a whole		    			    
				    $query .= ' ORDER BY '.$ordering.' ';
				    
				    
				    // Remove the limit that gets set and inherited from the last
				    // item in the loop of union selects
				   // $query = str_replace('LIMIT 0, '.$limit, '', $query);
				    
				    // If the total number of items is less than the count
				    if($total < $count) {
				    	$query .= ' LIMIT 0, ' . $total ;
				    } else {
				    	$query .= ' LIMIT 0, ' . $count ;
				    }
				    
				   
				    $db->setQuery($query);	
					
					// The final array    	    	    
				    $items = $db->setQuery($query)->loadObjectList();	
							
				}
				
		} else {
		
			
			$id = $params->get('easyblog_content_items', '');
			
			if($id!=="") {
				$id = implode(",", $id);	
				
				$db = JFactory::getDbo(); 
				$query = $db->getQuery(true); 
				$query->select(array('*')) 
				      ->from($db->quoteName('#__easyblog_post')) 
				      ->where('ID in ('.$id.')')
				      ->where('(publish_down = '.$db->Quote($nullDate).' OR publish_down >= '.$db->Quote($now).')')
				      ->where('publish_up <= '.$db->Quote($now))
				      ->where('published = 1');
				      
			      if($show_featured == 0) {
			      	$query->where('frontpage = 0');
			      } elseif($show_featured == 1) {
			      	$query->where('frontpage = 1');
			      } 
			      
			      
			      if($show_archived == 0) {
			      		$query->where('state = 0');
			      } elseif($show_archived == 1) {
			      		$query->where('state = 2');
			      } elseif($show_archived == 3) {
			      		$query->where('state in (0,2)');
			      }
				      
				$query->order(''.$ordering.'');
				$query->setLimit($count, $offset);
				$db->setQuery($query,0); 
				$items = $db->loadObjectList(); 
				
	
			} else {
				echo '<div class="alert alert-warning">';
				echo JText::_('NO_ITEMS_SELECTED');
				echo '</div>';
				return;
			}
		  }
		
		// counter
		$i = 1;
		
		
		
		// Manual Links
		$manual_links = null;
		
		if($link_type =="manual") {
			$manual_links = explode(PHP_EOL, $params->get('joomla_manual_links'));
		}
		
		if(is_array($items)) {
			
			foreach ($items as $key => $item)
			{
				
				
				/**************************************************
				 * Link
				 *************************************************/
				
				$category = self::get_easyblog_cat($item->category_id); 
			
				$item->category = $category[0]->title;
				$item->category_title = $item->category;
				$item->category_alias = $category[0]->alias; 
				$item->catlink = EasyBlogRouter::getRoutedURL('index.php?option=com_easyblog&view=categories&layout=listings&id=' . $item->category_id, false, true );
				$item->slug = $item->id . ':' . $item->permalink;
				$item->catslug = $item->category_id . ':' . $item->category_alias;
			
				$item->link = null;
					
				if($link_type =="manual") {
					if(isset($manual_links[$key])) {
						$item->link = $manual_links[$key];
					}  else {
						if($link_fallback) {
								$item->link = EasyBlogRouter::getRoutedURL('index.php?option=com_easyblog&view=entry&id=' . $item->id, false, true );
							} else {
								$item->link = null;
							}
					}
					
				} else {
					
					if (in_array($item->access, $authorised))
							{
							// We know that user has the privilege to view the article
							$item->link = EasyBlogRouter::getRoutedURL('index.php?option=com_easyblog&view=entry&id=' . $item->id, false, true );
					}
					else
					{
						$item->link = EasyBlogRouter::getRoutedURL('index.php?option=com_easyblog&view=entry&id=' . $item->id, false, true );
					}
					
					if($strict_readmore && $item->content =="") {
						$item->link = null;
					}
				}
								
				
				// Introtext
				$item->introtext = $item->intro;
				$item->fulltext = $item->content;
				
				/**************************************************
				 * Category
				 *************************************************/
				 
				$item->category = $item->category_title;
				
				if($access) {
	            // 	$item->catlink = JRoute::_(ContentHelperRoute::getCategoryRoute($item->catslug).'&layout=blog');
	            } else {
	            //    $item->catlink = JRoute::_('index.php?option=com_user&view=login');
	            }
				
				
				/**************************************************
				 * Image
				 *************************************************/
				$item->image = "";
				
				
				// Try to get image intro
				
				
				if($item->image!=="") {
					$item->image = $item->image;
				}
				
				// Check intro text
				if($item->image == "") {
					// Try to extract the first image from full text
					$imageHTML = $item->introtext;
					$imageHTML .= "alt='...' title='...' />";
	
					$pattern = '/<img[^>]+src[\\s=\'"]' . '+([^"\'>\\s]+)/is';
	
					if (preg_match($pattern, $imageHTML, $match)) {
						$item->image = (string) $match[1];
					}
				} 
				
				// Check fulltext
				if($item->image == "") {
					// Try to extract the first image from full text
					$imageHTML = $item->fulltext;
					$imageHTML .= "alt='...' title='...' />";
	
					$pattern = '/<img[^>]+src[\\s=\'"]' . '+([^"\'>\\s]+)/is';
	
					if (preg_match($pattern, $imageHTML, $match)) {
						$item->image = (string) $match[1];
					}
				} 
				
				if($item->image == "") {
					if($placeholder) {
						$item->image = $placeholder_path;
					} else {
						$item->image = "";
					}
				}
				
				
				
				
				$item->featured = $item->frontpage;
				$item->votes = $item->vote;
				
				
				
				/**************************************************
				 * Ratings
				 *************************************************/
				if($get_ratings) {	 
					$query = 'SELECT *' . ' FROM #__easyblog_ratings' . ' WHERE uid = ' . $item->id;
		            $db->setQuery($query);
		            $rating = $db->loadObject();
		            
		            if(isset($rating->value)) {
		            	$item->rating = ($rating->value) / 2;
					} else {
						$item->rating = 0;
					}
				} 
				
				
				
				/**************************************************
				 * Comments
				 *************************************************/
				if($get_comments) {	 
					$query = 'SELECT * FROM #__easyblog_comment' . ' WHERE post_id = ' . $item->id;
				    $db->setQuery($query);
				    $comments = $db->loadRowList();
				    $item->comments = count($comments);
				} 
				
				
				if($get_tags) {		
					
					
					/**************************************************
					 * Tags
					 *************************************************/
					$query = 'SELECT tag_id' . ' FROM #__easyblog_post_tag' . ' WHERE post_id = ' . $item->id;
					$db->setQuery($query);
					$tag_ids = $db->loadColumn();
					
					if(!empty($tag_ids)) {
						$query = 'SELECT *' . ' FROM #__easyblog_tag' . ' WHERE id in (' . implode(',', $tag_ids) . ')';
						$db->setQuery($query);
						$tags = $db->loadObjectLIst();
						
						$taglist = array();
						
						foreach ($tags as $key => $tag) {
							
							$title = $tag->title;
							$alias = $tag->alias;
							$id = $tag->id;
							
							$link = '';
							
							$tagdata = array(
								'title' => $title,
								'alias' => $alias,
								'link' => $link
							);
							
							$taglist[$alias] = (object)$tagdata;
						}
					} else {
						$taglist = "";
					}
				}
				
				/**************************************************
				 * Author
				 *************************************************/
				$author = 'SELECT * FROM #__easyblog_users' . ' WHERE id = ' . $item->created_by;
				$db->setQuery($author);
				$author = $db->loadObject();
				$item->author = $author->nickname;
				
				
				$item->authorlink = EasyBlogRouter::getRoutedURL( 'index.php?option=com_easyblog&view=blogger&layout=listings&id=' . $author->id , false , true );
			
				if($author->avatar =="") {
					$item->avatar = "components/com_easyblog/assets/images/default_blogger.png";
				} else {
					$item->avatar = 'images/easyblog_avatar/' . $author->avatar;
				}
				 
				
				
				
				/**************************************************
				 * Date
				 *************************************************/
				$item->date = $item->created;
				$item->publishdate = $item->publish_up;
				
				
				// Time Since
				$item->time_since = self::humanTiming(strtotime($item->publishdate));
				
				
				/**************************************************
				 * Video
				 *************************************************/
				 
				preg_match('#<iframe([^>]+)><\/iframe>#', $item->content, $item->video);
				if(isset($item->video[0])) {
					$item->video = $item->video[0];
				} else {
					$item->video = false;
				}
				
				$item->video_url = "";
				
				if($item->video) {
					$item->video_url = preg_match('/src="([^"]+)"/', $item->video, $match);
					$item->video_url = $match[1];
				}
				// Turn the array back into an object
				$item->tags = $taglist;
				
				$item->pinit ="";
				
				$i ++;
			}
	
			return $items;
		}
	}
	
	public static function get_easyblog_cat($category) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('title', 'alias')) 
		      ->from($db->quoteName('#__easyblog_category')) 
			  ->setLimit(1)
			  ->where($db->quoteName('id') . ' LIKE '. $category);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
	
	public static function humanTiming ($time)
	{
	
	    $time = time() - $time; // to get the time since that moment
	    $time = ($time<1)? 1 : $time;
	    $tokens = array (
	        31536000 => 'year',
	        2592000 => 'month',
	        604800 => 'week',
	        86400 => 'day',
	        3600 => 'hour',
	        60 => 'minute',
	        1 => 'second'
	    );
	
	    foreach ($tokens as $unit => $text) {
	        if ($time < $unit) continue;
	        $numberOfUnits = floor($time / $unit);
	        return $numberOfUnits.' '.$text.(($numberOfUnits>1)?'s':'');
	    }
	
	}
	
}
