<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;


/**
 * Helper for mod_articles_latest
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 * @since       1.6.0
 */
abstract class images
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList(&$params)
	{
		//Remove Slashes from directory
		
		$directories = json_decode($params->get('directory_limit'));
		
		
		if(is_object($directories)) {
			
			require_once __DIR__ . '/../includes/zentools2helper.php';
			
			// Instantiate the class
			$zen = new ZenTools2Helper();
			
			// Number of images
			$count = (int) $params->get('image_count', '9');
			
			// Title delimiter
			// Changed to an array
			$separator = $params->get('separator', '-');
			
			// Link Type
			$link_type = $params->get('image_link_type', 'item');
			$link_fallback = $params->get('link_image_fallback');
			
			// Prefix in front of the title
			$prefix = $params->get('use_prefix', 0);
			
			// Recursive search
			$child_folders = $params->get('child_folders', 1);
			
			// Return folder
			$include_folder = "1";
			
			// Items to exclude
			$exclude = array('.');
			
			// list of filetypes you want to show
			$allowed_types = '\.png$|\.gif$|\.jpg$|\.jpeg$|\.PNG$|\.GIF$|\.JPG$|\.JPEG$|\.$';
			
			//we create the array that will hold the items
			$items = array();
			$images = array();
			$new = "";
			
			// Ordering and scope
			$ordering = $params->get('image_ordering');
			$within_cat_ordering = $params->get('within_cat_ordering');
			
			$scope = $params->get('sort_scope');
			
			$use_exif = $params->get('use_exif');
			
			//create an array of items for template
				foreach ($directories as $directory => $limit) {
					
					if($limit == "") {
						$limit = $count;
					}
					
				
					// Get the directory name and limit		
					$directory = ltrim($directory,'/');
					$directory = rtrim($directory,'/');	
					$folder = $zen->get_folder_name($directory);
					$image_list = JFolder::files($directory, $filter = $allowed_types,$child_folders, $include_folder , $exclude);
					
					if(!empty($image_list)) {
					
						$folder_images = array();
						$images = array();
						
						$limit_count = 1;
						
						// Retrieve data from each image in the folder
						foreach ($image_list as $key => $array_item) {
							
							$image_array = array();


							if ((strpos(JPATH_ROOT, '/'))===FALSE){//windows
								$array_item = str_replace('\\', '/', $array_item);
							} 

							$image_name = JFile::getName($array_item);
							$image_name = JFile::stripExt($image_name);
							$image_array[$image_name]['image'] = $array_item; 
							$image_array[$image_name]['folder'] = $folder; 
							$image_array[$image_name]['name'] = $image_name; 
							$image_array[$image_name]['limit'] = $limit; 
							

							if($scope) {
								// Sort within folders
								$folder_images[$image_name] = $image_array;
							
							} else {
								
								if($limit_count <= $limit) {
									$folder_images[$image_name] = $image_array;
								}
								
								else {
									break;
								}
								
								$limit_count ++;
							}
						}
					
						
						// Set folder count variable
						${$folder.'_count'} = 0;
						${$folder.'_limit'} = $limit;
						
						${$folder.'_array'} = $folder;
						
						
						// See if we are sorting images insode each folder first 
						if($scope) {
							
							// Sort within folders
							if ($within_cat_ordering == 'random')
							{
								shuffle($folder_images);
							
							} elseif($within_cat_ordering == 'title_reverse') 
							{
							
								krsort ($folder_images);
							}
							
							${$folder.'_array'} = array_slice($folder_images, 0, $limit);
							
							foreach(${$folder.'_array'} as $image=>$details) {
							    $new[$folder . '-' .$image] = $details;
							}
						 } else {
						 	
						 	foreach ($folder_images as $key => $image) {
						 		
						 		$new[$key] = $image;
						 	}
						 }
					}
				
				
				
				else {
					
					return;
				}
			}
				
			// Flatten the array of images
			// We get this because we cast items to an array 			
			if(is_array($new)) {
				foreach ($new as $key => $image) {
					
					foreach ($image as $key => $item) {
						
						$name = $item['name'];
						$images[$name] = $item;
					}
				}
			}
			
			// This is the ordering that takes place 
			// after items have been referenced in the folder.
			// If not ordering within the folder we just jump staright to here. 
			if ($ordering == 'random')
			{
				shuffle($images);
			
			} elseif($ordering == 'title_reverse') 
			{
				krsort ($images);
				
			} else {
				
				ksort($images);
			}
			
			
			// Just in case the folder count is higher than module count
			
			$array_count = count($images);
			
			if($array_count > $count) {
				$images = array_slice($images, ($array_count - $count));
			}
			
			
			// Manual Links
			$manual_links = null;
			
			if($link_type =="manual" || $link_type =="manual_or_image") {
				$manual_links = explode(PHP_EOL, $params->get('image_manual_links'));
			}
			
			
			$i = 0;
			
			// Set the counter
			foreach($images as $key=>$image) {
				
			//	foreach ($single_image as $key => $image_stuff) {
				//foreach($single_image as $image) {
					
					$folder = $image['folder'];
					$image = $image['image'];
					
					$folder_limit = ${$folder.'_limit'};
					
					// Check image count for that folder
					if (${$folder.'_count'} >= $folder_limit) break;
	
					//windows or linux, find local
					$local_image = str_replace('\\', '/', $image);
					$pos = strpos($local_image, '/images');
					if($pos !== false){
						$local_image = substr_replace($local_image, '', 0, $pos);
					}
					
					// remove file path
					$file = JFile::getName($image);
					
					// remove file extension
					$name = JFile::stripExt($file);
					$clean_name = $zen->readable($name);
					
					// Create the new class
					$item = new stdClass();
											
					// Store the image name
					$item->image = $image;
					
					// Exif Data
					if($use_exif) {
						require_once JPATH_ROOT . '/modules/mod_zentools2/includes/exif_reader.php';
						$image = str_replace('../', '/', $image);
						$exif_data = new KEHA76_Exif_Reader();
						$read_image =  JPATH_ROOT .'/'.$image;
						$exif = $exif_data->getDetails($read_image);
						
						$item->exif = $exif;
					} else {
						$item->exif = null;
					}
					
					if($link_type =="manual") {
						
						if(isset($manual_links[$i])) {
							$item->link = $manual_links[$i];
						} else {
							if($link_fallback) {
								$item->link = $image;
							} else {
								$item->link = null;
							}
						}
					
					} else {
						$item->link = $image;
					}
					
					
					// Item Title check for and remove prefix eg 01.photo.jpg becomes photo.jpg
					if($prefix) {
						$item->title = strstr($name, '.');
						$item->title = ltrim($item->title, '.');
						$item->title = $zen->readable($item->title, $separator);
					} else {
						
						$item->title = $zen->readable($name, $separator);
					}
					
					// Fake the categories
					$item->category = $folder;
					$item->category_alias = $zen->clean($folder);
					
					// Tags that should be nulled
					$item->date = false;
					$item->created= false;
					$item->text= false;
					$item->catlink = "";
					$item->featured = 0;
					$item->newlink = 0;
					//$item->$id = false;
					$item->video =false;
					$item->video_url="";
					$item->authorLink=false;
					$item->author=false;
					$item->avatar=false;
					$item->introtext=false;
					$item->tagblock=false;
					$item->tags=null;
					$item->rating="";
					$item->fulltext = false;
				
					// Increment the count
					${$folder.'_count'} ++;
							
					// Add all items to an array
					$items[] = $item;
					
					// Increment count
					$i++;
				//}
			//	}
			}
			
			// Return the items
			return $items;
		}
		
	}
}
