<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;





/**
 * Helper for mod_articles_latest
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 * @since       1.6.0
 */
abstract class joomla_contacts
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList($params)
	{
		
		$cats = json_decode($params->get('joomla_contacts_categories_limit', ''));
		$show_featured = $params->get('joomla_contacts_featured', '');
		$order = $params->get('joomla_contacts_ordering', 'name DESC');	
		$count = $params->get('j_contact_count', '5');
		
	
		// Cast object to an array
		$catitems = (array)$cats;
		
		// Get catids from array
		$catids = array_keys($catitems);
		
		// Count number of cats to process
		$limitcount = count($catitems);
		
		// Link Type
		$link_type = $params->get('jcontact_link_type', 'item');
		$link_fallback = $params->get('jcontact_link_fallback');
		
		// Access filter
		$access     = !JComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		
		$user = JFactory::getUser();
		
		// Get view access levels for current user id
		$viewLevels = JAccess::getAuthorisedViewLevels(JUserHelper::getUserId($user->username));
		$access_levels = implode(",", $viewLevels);	
		
		// Placeholder images
		$placeholder = 0;
		$placeholder_path = "";
		$settings = json_decode($params->get('layout_settings'));
		
		foreach($settings as $key=>$colcontent) {
		
			foreach ($colcontent as $name =>$item_content) {
						    	
		    	if($name == 'image') {
		    		if(isset($item_content->placeholder)) {
		    			$placeholder = $item_content->placeholder;
		    			$placeholder_path = $item_content->placeholder_path;	
		    		}
		    	}
		    }
		}
		
		// If just a single value then proceed as usual
		if($limitcount <= 1) {
		
			// If no limits on category numbers we just perform the standard query
			$db = JFactory::getDBO();
			$query	= $db->getQuery(true);
			$query->select('a.*');
			$query->from('#__contact_details AS a'); 
			
			if(!empty($catids)) {
				$query->where('a.catid in (' . implode(',', $catids) . ')');
			    $query->where('a.published = 1');
			}
			
			// Featured
			if($show_featured == 0) {
				$query->where('a.featured = 0');
			} elseif($show_featured == 1) {
				$query->where('a.featured = 1');
			} 
			
			$query->where('published = 1')
					  ->where("access in ($access_levels)");
			
			if(isset($catids[0])) {
				$limit = $catids[0];
				
				if($limit > $count) {
					$limit = $count;
				}
				
			} else {
				$limit = $count;
			}
			
			
			if($order =='title') {
				
				$query->order('name ASC');
				
			} elseif($order =='title_reverse') {
				
				$query->order('name DESC');
				
			} elseif($order =='random') {
			
				$query->order('RAND()');
				
			} elseif($order =='order') {
			
				$query->order('ordering ASC');
			
			} elseif($order =='order_reverse') {
			
				$query->order('ordering DESC');
			
			} 
			

			$db->setQuery($query, 0, $limit);
			$contacts = $db->loadObjectList();
			
		} else {
		
			// Get items from each category limited by number set in admin
			// To do this we need to union the selects
			// and then apply an order at the end
			
			$db = JFactory::getDbo();
			$query = $db->getQuery(true);
			
			// Loops through the catd ids and limits set
			// catid:limit
			// 42:2
		
			// We need to calculate the new total items to display
			// Check later to see if it's higher or lower than the count amount
			$total = '';
		
			foreach ($cats as $catid => $limit) {
				
				
				// If limit is left blank in the settings
				if($limit == "") {
					$limit = $count;
				}
				
				// Set up the union query
				${'q'.$catid} = $db->getQuery(true);
				
				// Create the select for each cat
				${'q'.$catid}
				    ->select('*')
				    ->from('#__contact_details')
				   	->where('published = 1')
				    ->where('catid = '.$catid.'')
				   	->where("access in ($access_levels)");
				   
				   if($order =='title') {
				   		${'q'.$catid}->order('name ASC');
				   } elseif($order =='title_reverse') {	
					   	${'q'.$catid}->order('name DESC');			   	
				   } elseif($order =='random') {
					   	${'q'.$catid}->order('RAND()');			   	
				   } elseif($order =='order') {
					   	${'q'.$catid}->order('ordering ASC');			   
				   } elseif($order =='order_reverse') {
					   	${'q'.$catid}->order('ordering DESC');			   
				   } 
				   
				   
				   
				   // Featured items
				    if($show_featured == 0) {
				    	${'q'.$catid}->where('featured = 0');
				    } elseif($show_featured == 1) {
				    	${'q'.$catid}->where('featured = 1');
				    } 
				    
				    // Limit the items from this category
				    ${'q'.$catid}->setLimit($limit);
				    
				    $total += $limit;
			}
					
			// Perform the base query
			// First item is a dummy
			// Then loop through the unions
			// created int he previous step
			
			$query
			    ->select('*')
			    ->from('#__contact_details')
			    ->where('1 = 0');
			    
			 foreach ($cats as $catid => $limit) {
			   	$query->union(${'q'.$catid});
			 }
			 
			if($order =='title') {
				//$query->order('name ASC');
				$query .= ' ORDER BY name ASC ';
				
			} elseif($order =='title_reverse') {
				
				//$query->order('name DESC');
				$query .= ' ORDER BY name DESC ';
				
			} elseif($order =='random') {
			
				//$query->order('RAND()');
				$query .= ' ORDER BY RAND() ';
				
			} elseif($order =='order') {
			
				//$query->order('ordering ASC');
				$query .= ' ORDER BY ordering ASC ';
			
			} elseif($order =='order_reverse') {
			
				//$query->order('ordering DESC');
				$query .= ' ORDER BY ordering DESC ';
			
			} 
			
			// If the total number of items is less than the count
		    if($total < $count) {
		    	$query .= ' LIMIT ' . $total ;
		    } else {
		    	$query .= ' LIMIT  ' . $count ;
		    }
		    // Set the query
		    $db->setQuery($query);	
			
			// The final array    	    	    
		    $contacts = $db->setQuery($query)->loadObjectList();	
					
		}
		
		// Manual Links
		$manual_links = null;
		
		if($link_type =="manual") {
			$manual_links = explode(PHP_EOL, $params->get('jcontact_manual_links'));
		}
		
		if(is_array($contacts)) {
			foreach ($contacts as $key=>$contact)
			{		
				// Create the new class
				$item = new stdClass();
										
				// Store the image name
				$item->image = $contact->image;
				
				if($item->image !=="") {
					$item->image = $contact->image;
					
				} else {
					
					if($placeholder) {
						$item->image = $placeholder_path;
					} else {
						$item->image = "";
					}
					
				}
				
				
				// Item Title
				$item->title = $contact->name;
				
				// Item Text
				$item->text = false;
				
				if($link_type =="manual") {
					
					if(isset($manual_links[$key])) {
					
						$item->link = $manual_links[$key];
					
					}  else {
					
						if($link_fallback) {
							$item->link = "index.php?option=com_contact&view=contact&id=".$contact->id;
						} else {
							$item->link = null;
						}
					}
				}
				else {
					$item->link = "index.php?option=com_contact&view=contact&id=".$contact->id;
				}
				
				$item->readmore = $item->link;
				$item->position = $contact->con_position;
				$item->address = $contact->address;
				$item->state = $contact->state;
				$item->city = $contact->suburb;
				$item->country = $contact->country;
				$item->postcode = $contact->postcode;
				$item->telephone = $contact->telephone;
				$item->fax = $contact->fax;
				$item->misc = $contact->misc;
				$item->url = $contact->webpage;
				$item->email = $contact->email_to;
				$item->featured = $contact->featured;
				
				// Category
				$category = self::get_contact_cat($contact->catid); 
				$item->category = $category[0]->title;
				$item->category_alias = $category[0]->alias; 
				$item->catlink = 'index.php?option=com_contact&view=category&id='.$contact->catid;
				
				// Date
				$item->date = $contact->created;
				$item->publishdate = $contact->publish_up;
				
				// Tags that should be nulled
				$item->created= false;
				$item->newlink = 0;
				//$item->$id = false;
				$item->video =false;
				$item->authorLink=false;
				$item->author=false;
				$item->avatar=false;
				$item->introtext=false;
				$item->tagblock=false;
				$item->tags=false;
				$item->rating="";
				$item->fulltext = false;				
				
				// Add all items to an array
				$items[] = $item;
			}
			
			return $items;
		}
	}
	
	
	public static function get_contact_cat($category) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('title', 'alias')) 
		      ->from($db->quoteName('#__categories')) 
			  ->setLimit(1)
			  ->where($db->quoteName('id') . ' LIKE '. $category);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
}
