<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

require_once JPATH_SITE . '/components/com_content/helpers/route.php';

JModelLegacy::addIncludePath(JPATH_SITE . '/components/com_content/models', 'ContentModel');

jimport('joomla.user.helper');
jimport('joomla.access.access');


/**
 * Helper for mod_articles_latest
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 * @since       1.6.0
 */
abstract class joomla_tag_content
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList(&$params)
	{
		
		// Children?
		$get_children = $params->get('joomla_get_children', 0);
		
		// Featured
		$show_featured = $params->get('joomla_tag_featured', '');
		
		// Archived
		$show_archived = $params->get('joomla_tag_archived', '0');
		
		// Ordering
		$ordering = $params->get('joomla_tag_ordering', 'title DESC');	
		
		// Item count
		$count = $params->get('joomla_tag_count', '5');
		$offset = $params->get('joomla_tag_offset', '0');
		
		// Link Type
		$link_type = $params->get('joomla_tag_link_type', 'item');
		$link_fallback = $params->get('joomla_tag_link_fallback');
		
		
		
		// Set current time to see if items should be published
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		$nullDate	= $db->getNullDate();
		$date = JFactory::getDate();
		$now = $date->toSql();
		
		// Get the layout item settings
		// We need this to get some of the values for related items.
		
		$settings = json_decode($params->get('layout_settings'));
		
		$strict_readmore = 0;
		
		$placeholder = 0;
		$placeholder_path = "";
		
		$fulltext_placeholder = 0;
		$fulltext_placeholder_path = "";
		
		foreach($settings as $key=>$colcontent) {
		
			foreach ($colcontent as $name =>$item_content) {
				if($name == 'readmore') {
		    		if(isset($item_content->strict_readmore)) {
		    			$strict_readmore = $item_content->strict_readmore;
		    		}
		    	}
		    	
		    	if($name == 'image') {
		    		if(isset($item_content->placeholder)) {
		    			$placeholder = $item_content->placeholder;
		    			$placeholder_path = $item_content->placeholder_path;	
		    		}
		    	}
		    	
		    	if($name == 'fulltext_image') {
		    		if(isset($item_content->placeholder)) {
		    			$fulltext_placeholder = $item_content->placeholder;
		    			$fulltext_placeholder_path = $item_content->placeholder_path;	
		    		}
		    	}
		    }
		}
		
		
		
		// Access filter
		$access     = !JComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		
		
		// Get view access levels for current user id
		$user = JFactory::getUser();
		$viewLevels = JAccess::getAuthorisedViewLevels(JUserHelper::getUserId($user->username));
		$access_levels = implode(",", $viewLevels);	
		
	
		$cats = json_decode($params->get('joomla_tag_content_categories_limit', ''));
	
		// Cast object to an array
		$catitems = (array)$cats;
		
		// Get catids from array
		$catids = array_keys($catitems);
		
		// Count number of cats to process
		$limitcount = count($catitems);
		
		
		// Get Child categories
		if($get_children) {
			$child_categories = self::get_tag_child_cat($catids);
			$catids = array_merge($catids, $child_categories);
		}
		
		
		// Get the content items based on their tag id
		if(!empty($catids)) {
			
			
			if($limitcount <= 1) {
				// If we are just getting content from one tag
				$query->select('content_item_id');
				$query->from('#__contentitem_tag_map'); 
				$query->where('tag_id in (' . implode(',', $catids).')');
				$db->setQuery($query, 0);
				$ids = $db->loadColumn();
		
				// Get the actual items
				// Define DB
				$db = JFactory::getDbo();
				$query = $db->getQuery(true);
				
				$query->select(array('*')) 
				      ->from($db->quoteName('#__content')) 
				      ->where('ID in ('.implode(',', $ids).')')
				      ->where('(publish_down = '.$db->Quote($nullDate).' OR publish_down >= '.$db->Quote($now).')')
				      ->where('publish_up <= '.$db->Quote($now))
				      ->where("access in ($access_levels)");
				      
				if($show_featured == 0) {
				  	$query->where('featured = 0');
				} elseif($show_featured == 1) {
				  	$query->where('featured = 1');
				} 
							  
				if($show_archived == 0) {
				  	$query->where('state = 1');
				} elseif($show_archived == 1) {
				  	$query->where('state = 2');
				} elseif($show_archived == 3) {
				  	$query->where('state in (1,2)');
				}
				      
				$query->order(''.$ordering.'');
				$query->setLimit($count, $offset);
				$db->setQuery($query,0); 
				$items = $db->loadObjectList();
				
			
			} else {
			
				// We need to get more than one tag so we need to retrieve from the
				// Content tag map first for each item
				// If we are getting from more than one tag
				
				// Array to store the items in later
				$get_items = array();
				
				foreach ($cats as $catid => $limit) {
				
					// Create an array we use later for this tag so we can store the limit
					$get_items[$catid] = array();
					$get_items[$catid]['limit'] = $limit;
					
					// Set up the union query
					${'q'.$catid} = $db->getQuery(true);
				
					// Create the select for each cat
					${'q'.$catid}
					    ->select('tag_id,content_item_id')
					    ->from('#__contentitem_tag_map')
					    ->where('tag_id = '.$catid.'');
				}
						
				$query
				    ->select('tag_id,content_item_id')
				    ->from('#__contentitem_tag_map')
				    ->where('1 = 0');
					    
				foreach ($cats as $catid => $limit) {
				   	$query->union(${'q'.$catid});
				}
					 
					 
				$db->setQuery($query);	
					
				// The array of items we need to retrieve with their tag id 	    	    
				$tag_items = $db->setQuery($query)->loadAssocList();	
				
				foreach ($catids as $catid) {
					foreach ($tag_items as $key =>$item) {
						if($item['tag_id'] == $catid) {
							$get_items[$catid][] = $item['content_item_id'];
						}
					}
				}
				
				// Get the actual items
				// Define DB
				$db = JFactory::getDbo();
				$query = $db->getQuery(true);
				$total = '';
				
				foreach ($get_items as $tag_id =>$get_item) {
					
					$limit = $get_item['limit'];
					$ids = array_slice($get_item, 1);
					$ids = implode(',',$ids);
					
					// Check if it's been set otherwise revert to count
					if($limit == "") {
						$limit = $count;
					}
					
					// Set up the union query
					${'q'.$tag_id} = $db->getQuery(true);
				
					// Create the select for each tag
					${'q'.$tag_id}
					    ->select('*')
					    ->from('#__content')
					    ->where("id in ('$ids')")
					    ->where("access in ($access_levels)")
					    ->where('(publish_down = '.$db->Quote($nullDate).' OR publish_down >= '.$db->Quote($now).')')
					    ->where('publish_up <= '.$db->Quote($now))
					    ->order(''.$ordering.'');
					 
					 	// Featured items
					    if($show_featured == 0) {
					    	${'q'.$tag_id}->where('featured = 0');
					    } elseif($show_featured == 1) {
					    	${'q'.$tag_id}->where('featured = 1');
					    } 
					    
					    if($show_archived == 0) {
					    	${'q'.$tag_id}->where('state = 1');
					    } elseif($show_archived == 1) {
					    	${'q'.$tag_id}->where('state = 2');
					    } elseif($show_archived == 2) {
					    	${'q'.$tag_id}->where('state in (1,2)');
					    }
					    
					    // Limit the items from this category
					    ${'q'.$tag_id}->setLimit($limit,$offset);
					    
					    $total += $limit;
				    }
				
							
				
					// Start the union with a dummy sql
						$query->select('*')
					    ->from('#__content')
					    ->where('1 = 0');
					    
					foreach ($get_items as $tag_id => $get_item) {
					 	  	$query->union(${'q'.$tag_id});
					}
					 
					 
					// Add the order by option
					// A bug in Joomla currently means that we have to
					// Set this manually
				
				 
				 // Set the limit for the items as a whole		    			    
				 $query .= ' ORDER BY '.$ordering.' ';
				 
				 
				 // Remove the limit that gets set and inherited from the last
				 // item in the loop of union selects
				$query = str_replace('LIMIT 0, '.$limit, '', $query);
				 
				 // If the total number of items is less than the count
				 if($total < $count) {
				 	$query .= ' LIMIT 0, ' . $total ;
				 } else {
				 	$query .= ' LIMIT 0, ' . $count ;
				 }
			
				$db->setQuery($query);	
					
				// The final array    	    	    
				$items = $db->setQuery($query)->loadObjectList();
			}
		
		
			$total = '';
			
			// counter
			$i = 1;
			
			// Manual Links
			$manual_links = null;
			
			if($link_type =="manual") {
				$manual_links = explode(PHP_EOL, $params->get('joomla_manual_links'));
			}
		
		}
		else {
			return;
		}
		
	
		if(is_array($items)) {
			
			foreach ($items as $key => $item)
			{
				
				/**************************************************
				 * Link
				 *************************************************/
				
				$category = self::get_joomla_cat($item->catid); 
			
				$item->category = $category[0]->title;
				$item->category_title = $item->category;
				$item->category_alias = $category[0]->alias; 
				$item->catlink = 'index.php?option=com_contact&view=category&id='.$item->catid;
				$item->slug = $item->id . ':' . $item->alias;
				$item->catslug = $item->catid . ':' . $item->category_alias;
			
				$item->link = null;
					
				if($link_type =="manual") {
					if(isset($manual_links[$key])) {
						$item->link = $manual_links[$key];
					}  else {
						if($link_fallback) {
								$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
							} else {
								$item->link = null;
							}
					}
				
				} elseif($link_type == "alternate") {
					
					 $altlinks = json_decode($item->urls);
					
                    	if(isset($altlinks->urla) and !empty($altlinks->urla)) {
                    	    $item->link = $altlinks->urla;
                    	} else {
                    		
                    		if($link_fallback) {
                    		
                    			$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
                    		} else {
                    			$item->link = null;
                    		}
                    	}
				
				} else {
					
					if (in_array($item->access, $authorised))
							{
							// We know that user has the privilege to view the article
							$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
					}
					else
					{
						$item->link = JRoute::_('index.php?option=com_users&view=login');
					}
					
					if($strict_readmore && $item->fulltext =="") {
						$item->link = null;
					}
				}
				
				
				
				
				
				/**************************************************
				 * Category
				 *************************************************/
				 
				$item->category = $item->category_title;
				
				if($access) {
	             	$item->catlink = JRoute::_(ContentHelperRoute::getCategoryRoute($item->catslug).'&layout=blog');
	            } else {
	                $item->catlink = JRoute::_('index.php?option=com_user&view=login');
	            }
				
				
				/**************************************************
				 * Image
				 *************************************************/
				$item->image = "";
				$item->fulltext_image = "";
				$images = json_decode($item->images);
				
				
				// Try to get image intro
				if (isset($images->image_intro) and !empty($images->image_intro)) {
					$item->image = $images->image_intro;		
				}
				else {
					// Try to extract the first image from full text
					$imageHTML = $item->introtext;
					$imageHTML .= "alt='...' title='...' />";
	
					$pattern = '/<img[^>]+src[\\s=\'"]' . '+([^"\'>\\s]+)/is';
	
					if (preg_match($pattern, $imageHTML, $match)) {
						$item->image = (string) $match[1];
					}
				}
				
				if($item->image == "") {
					if($placeholder) {
						$item->image = $placeholder_path;
					} else {
						$item->image = "";
					}
				}
				
				
				// Fulltext
				// Try to get image Fulltext
				if (isset($images->image_fulltext) and !empty($images->image_fulltext)) {
					$item->fulltext_image = $images->image_fulltext;		
				}
				else {
					
					if($item->fulltext_image == "") {
						if($placeholder) {
							$item->fulltext_image = $placeholder_path;
						} else {
							$item->fulltext_image = "";
						}
					}
				}
				
				
				
				
				
			
				/**************************************************
				 * Meta
				 *************************************************/
				
				$item->metadescription = $item->metadesc;
				
				
				/**************************************************
				 * Ratings
				 *************************************************/
				 
				$query = 'SELECT *' . ' FROM #__content_rating' . ' WHERE content_id = ' . $item->id;
	            $db->setQuery($query);
	            $rating = $db->loadObject();
	            
	            if(isset($rating->rating_sum)) {
	            	$item->rating = $rating->rating_sum;
				} else {
					$item->rating = 0;
				}
				
							
				/**************************************************
				 * Tags
				 *************************************************/
				$article_tags = new JHelperTags;      
				$item->tag_filter = $article_tags->getItemTags('com_content.article', $item->id);
				$item->tagLayout = new JLayoutFile('joomla.content.tags');
				
				$item->tagblock = $item->tagLayout->render($item->tag_filter);
				
				$item->tags = $item->tagblock;
			
				$item->tags = $item->tag_filter;
				
				$taglist = array();
				
				foreach ($item->tags as $key => $tag) {
					
					$title = $tag->title;
					$alias = $tag->alias;
					$id = $tag->id;
					
					$link = JRoute::_(TagsHelperRoute::getTagRoute($id . '-' . $alias));
					
					$tagdata = array(
						'title' => $title,
						'alias' => $alias,
						'link' => $link
					);
					
					$taglist[$alias] = (object)$tagdata;
				}
				
				
				/**************************************************
				 * Author
				 *************************************************/
				$user = JFactory::getUser($item->created_by);
				$item->author = $user->name;
				
				
				/**************************************************
				 * Date
				 *************************************************/
				$item->date = $item->created;
				$item->publishdate = $item->publish_up;
				
				
				// Time Since
				$item->time_since = self::humanTiming(strtotime($item->publishdate));
				
				
				/**************************************************
				 * Video
				 *************************************************/
				 
				preg_match('#<iframe([^>]+)><\/iframe>#', $item->introtext, $item->video);
				if(isset($item->video[0])) {
					$item->video = $item->video[0];
				} else {
					$item->video = false;
				}
				
				$item->video_url = "";
				
				if($item->video) {
					$item->video_url = preg_match('/src="([^"]+)"/', $item->video, $match);
					$item->video_url = $match[1];
				}
				// Turn the array back into an object
				$item->tags = $taglist;
				
				$item->pinit ="";
				
				$i ++;
			}
	
			return $items;
		}
	}
	
	public static function get_joomla_cat($category) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('id','title', 'alias')) 
		      ->from($db->quoteName('#__categories')) 
			  ->setLimit(1)
			  ->where($db->quoteName('id') . ' LIKE '. $category);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
	
	
	public static function get_tag_child_cat($tags) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select('id') 
		      ->from($db->quoteName('#__tags'))
			  ->where('parent_id in ( ' . implode(',', $tags).')');
		$db->setQuery($query); 
		$rows = $db->loadColumn();
		return $rows;
	}
	
	public static function humanTiming ($time)
	{
	
	    $time = time() - $time; // to get the time since that moment
	    $time = ($time<1)? 1 : $time;
	    $tokens = array (
	        31536000 => 'year',
	        2592000 => 'month',
	        604800 => 'week',
	        86400 => 'day',
	        3600 => 'hour',
	        60 => 'minute',
	        1 => 'second'
	    );
	
	    foreach ($tokens as $unit => $text) {
	        if ($time < $unit) continue;
	        $numberOfUnits = floor($time / $unit);
	        return $numberOfUnits.' '.$text.(($numberOfUnits>1)?'s':'');
	    }
	
	}
	
}
