<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;


/**
 * Helper for mod_articles_latest
 *
 * @package     Joomla.Site
 * @subpackage  mod_articles_latest
 * @since       1.6.0
 */

// Load router class to get link 
JLoader::register('TagsHelperRoute', JPATH_BASE . '/components/com_tags/helpers/route.php'); 

abstract class joomla_tags
{
	/**
	 * Retrieve a list of article
	 *
	 * @param   JRegistry  &$params  module parameters
	 *
	 * @return  mixed
	 */
	public static function getList(&$params)
	{
	
		$cats = json_decode($params->get('joomla_tags_categories_limit', ''));
		$count = $params->get('j_tags_count', '5');
		$order = $params->get('joomla_tag_ordering', 'title');
		$display_child = $params->get('display_child', 1);
		
		// Cast object to an array
		$catitems = (array)$cats;
		
		// Get catids from array
		$catids = array_keys($catitems);
		
		// Count number of cats to process
		$limitcount = count($catitems);
		
		// Get view access levels for current user id
		$user = JFactory::getUser();
		$viewLevels = JAccess::getAuthorisedViewLevels(JUserHelper::getUserId($user->username));
		$access_levels = implode(",", $viewLevels);	
		
		// Link Type
		$link_type = $params->get('jtag_link_type', 'item');
		$link_fallback = $params->get('jtag_link_fallback');
		
		
		// Get Contact items
		$db		= JFactory::getDbo();
		$query	= $db->getQuery(true);
		$query->select('a.*');
		
		if($order =='title') {
			
			$query->order('a.title ASC');
			
		} elseif($order =='title_reverse') {
			
			$query->order('a.title DESC');
			
		} elseif($order =='random') {
		
			$query->order('RAND()');
			
		} elseif($order =='order') {
		
			$query->order('a.lft ASC');
		
		} elseif($order =='order_reverse') {
		
			$query->order('a.lft DESC');
		
		} 
		
		$query->from('#__tags AS a'); 	
		
		if(!empty($catitems)) {
			$query->where('id in ("' . implode('","', $catids).'")');
		}
		
		if(!$display_child) {
			$query->where('level < 2');
		}
		
		$query->where("access in ($access_levels)");
		 
		$db->setQuery($query, 0, $count);
		
		$tag_results = $db->loadObjectList();
		
		// Manual Links
		$manual_links = null;
		
		if($link_type =="manual") {
			$manual_links = explode(PHP_EOL, $params->get('jtag_manual_links'));
		}
		
		
		// Placeholder images
		$placeholder = 0;
		$placeholder_path = "";
		$settings = json_decode($params->get('layout_settings'));
		
		foreach($settings as $key=>$colcontent) {
		
			foreach ($colcontent as $name =>$item_content) {
						    	
		    	if($name == 'image') {
		    		if(isset($item_content->placeholder)) {
		    			$placeholder = $item_content->placeholder;
		    			$placeholder_path = $item_content->placeholder_path;	
		    		}
		    	}
		    }
		}
		
		
		if(is_array($tag_results)) {
			foreach ($tag_results as $key=>$tag)
			{
		
				// Tag link'
				$route = new TagsHelperRoute;
	
				// Quick way to filter the toor tag value
				if($tag->title !=="ROOT") {
				
					// Create the new class
					$item = new stdClass();
											
					// Store the image name
					$images = json_decode($tag->images);
					
					$item->image = "";
					
					if(isset($images->image_intro)) {
						if($images->image_intro !=="") {
							$item->image = $images->image_intro;
						} else {
							if($placeholder) {
								$item->image = $placeholder_path;
							}
						}
					}
					else {
						if($placeholder) {
							$item->image = $placeholder_path;
						} 
					}
					
					// Metadata
					$meta = json_decode($tag->metadata);
					
					// Item Title
					$item->title = $tag->title;
					$item->alias = $tag->alias;
					$item->introtext = $tag->description;
					
					
					// Link
					if($link_type =="manual") {
						
						if(isset($manual_links[$key])) {
						
							$item->link = $manual_links[$key];
						
						}  else {
						
							if($link_fallback) {
								$item->link = JRoute::_(TagsHelperRoute::getTagRoute($tag->id . '-' . $tag->alias));
								
							} else {
								$item->link = null;
							}
						}
					}
					else {
						$item->link = JRoute::_(TagsHelperRoute::getTagRoute($tag->id . '-' . $tag->alias));
						
					}
					
					
					if(isset($meta->author)) {
						$item->author = $meta->author;
					} else {
						$item->author = false;
					}
					
					// Category
					
					if($tag->parent_id) {
						$parent_tag = self::get_parent($tag->parent_id);
						$parent_tag = $parent_tag[0];
						$item->category = $parent_tag->title;
						$item->category_alias = $parent_tag->alias; 
					} else {
						$item->category = "Root";
						$item->category_alias = "root";
					}
				
					$item->date = $tag->created_time;
					$item->publishdate = $tag->publish_up;
					
					// Tags that should be nulled
					$item->created= false;
					$item->catlink = false;
					$item->featured = 0;
					$item->newlink = 0;
					//$item->$id = false;
					$item->video =false;
					$item->authorLink=false;
					$item->avatar=false;
					$item->tagblock=false;
					$item->tags=false;
					$item->rating="";
					$item->fulltext = false;					
					
					// Add all items to an array
					$items[] = $item;
				}
			}
			
			return $items;
		}
	}
	
	
	public static function get_parent($parent_id) {
		$db = JFactory::getDbo(); 
		$query = $db->getQuery(true); 
		$query->select(array('title', 'alias')) 
		      ->from($db->quoteName('#__tags')) 
		      ->setLimit(1)
			  ->where($db->quoteName('id') . ' = '. $parent_id);
		$db->setQuery($query); 
		$rows = $db->loadObjectList();
		return $rows;
	}
	
}
