<?php
/**
 * @version		$Id: helper.php 1832 2013-01-30 13:05:12Z lefteris.kavadas $
 * @package		K2
 * @author		JoomlaWorks http://www.joomlaworks.net
 * @copyright	Copyright (c) 2006 - 2013 JoomlaWorks Ltd. All rights reserved.
 * @license		GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
 */

// no direct access
defined('_JEXEC') or die;


class spotify
{

		/**
		 * Retrieve a list of article
		 *
		 * @param   JRegistry  &$params  module parameters
		 *
		 * @return  mixed
		 */
		public static function getList(&$params)
		{
		
		
			require_once __DIR__ . '/../includes/zentools2helper.php';
			
			// Instantiate the class
			$zen = new ZenTools2Helper();
			
	
			$string = str_replace(' ', '+', $params->get('search_string', ''));
			$type = $params->get('search_type', '');
			$country = $params->get('country', 'us');
			$cache_check = $params->get('spotify_cache_check', '80');
			
			// define number of items 
			$count = $params->get('spotify_count', '9');
			
			
			// Create cache folder
			$cache_folder = JPATH_ROOT.'/cache/mod_zentools2-spotify/';
			if (!JFolder::exists($cache_folder))
			{
				JFolder::create($cache_folder);
			}
			
			
			// Check if search has been cached and return relevant object
			$cached_response = $cache_folder.'/spotify-search-'.$string.'-'.$type.'.json';
			$api = 'https://api.spotify.com/v1/search?q='.$string.'&type='.$type.'&limit='.$count;
			$spotify = self::get_content($cached_response,$api,$cache_check,$zen);
				
			
			// Create the default object based on the query
			if($type =="track") {
				// Track search
				$spotify = $spotify->tracks->items;
				
			} elseif($type=="artist") {
				// Artist search
				$spotify = $spotify->artists->items;
			} else {
				// Album search
				$spotify = $spotify->albums->items;
			}
			
			
			$settings = json_decode($params->get('layout_settings'));
			$resize_image = 0;
			
			
			// Placeholder images
			$placeholder = 0;
			$placeholder_path = "";
			
						
			foreach($settings as $key=>$colcontent) {
				
				foreach ($colcontent as $name =>$item_content) {
					if($name == 'image') {
						if(isset($item_content->resize)) {
			    			$resize_image = $item_content->resize;
			    		}
			    		
			    		if(isset($item_content->placeholder)) {
			    			$placeholder = $item_content->placeholder;
			    			$placeholder_path = $item_content->placeholder_path;	
			    		}
			    	 }
			    }
			}
			
			// Check if we have some images to process
			if (is_array($spotify))
			{
			
				//create an array of items for template
				// We copuld just grab the array but we may want to add items
				// later like get item from images meta data.
				
				$items = array();
				$i = 0;
				
				foreach ($spotify as $item)
				{
				
					if ($i >= $count) break;
					
					
					// Images
					$image = "";
					
					// Store the image name
					if($type =="track") {
						$image = $item->album->images[0]->url;
						
					} elseif($type=="artist") {
						if(!empty($item->images[0]->url)) {
							$image = $item->images[0]->url;
						} 
					} else {
						if(!empty($item->images[0]->url)) {
							$image = $item->images[0]->url;
						}
					}
					
					if($image == "" && $placeholder) {
						$image = $placeholder_path;
					}
					
					
					if($resize_image) {
						$item->image = $zen->handleRemoteImage($image);
					}
					else {
						$item->image = $image;
					}
					
					
					// Title
					$item->title = $item->name;
					
					// Link
					$item->link = $item->external_urls->spotify;
					
					// Create array to hold artist name / can be multiple
					$item->artist = array();
					
					if($type =="track") {
					
						// Get preview id
						$item->preview = $item->id;
						
						// No date available for tracks
						$item->date = false;
						
						$item->category_alias = '';
						$item->category = '';
						
						// Gte array of artists
						foreach ($item->artists as $key => $artist) {
							$item->artist[$artist->name] = $artist->external_urls->spotify;
							$item->category_alias .= $zen->clean($artist->name);
							$item->category .= $artist->name . ' ';
						}
						
						$item->tracklist = null;
						
					} elseif($type=="artist") {
						
						// Gte top tracks from artist
						$tracks = 'https://api.spotify.com/v1/artists/'.$item->id.'/top-tracks?country='.$country;
						$cached_tracks_response = $cache_folder.'/spotify-'.$type.'-toptracks-'.$item->id.'-data-'.$string.'-'.$type.'.json';
						$tracks = self::get_content($cached_tracks_response,$tracks,$cache_check,$zen);
						
						//echo '<pre>';
						//print_r($tracks);
						//echo '</pre>';
						$tracks = $tracks->tracks;
						
						// Get multiple id's to preview
						$preview = array();
						$tracklist = array();
						
						foreach ($tracks as $key => $track) {
							$preview[] = $track->id;
							$tracklist[$track->name] = $track->external_urls->spotify;
						}
						
						$item->tracklist = $tracklist;
						$item->preview = implode(',', $preview);
						
						// No date available for this view
						$item->date = false;
						
						// Artist name
						// We already have it since thats the kind of search query
						$item->artist[$item->name] = $item->external_urls->spotify;
						
						
						$item->category_alias = $zen->clean($item->title);
						$item->category = $item->title;
						
					} else {
						
						// Albums
						// Get Preview urls
						// Album details
						$album = 'https://api.spotify.com/v1/albums/'.$item->id;
						$cached_album_response = $cache_folder.'/spotify-'.$type.'-album-'.$item->id.'-data-'.$string.'-'.$type.'.json';
						$album = self::get_content($cached_album_response,$album,$cache_check,$zen);
						
						// Get tracks on the album
						$tracks = $album->tracks->items;
						$preview = array();
						$tracklist = array();
						
						foreach ($tracks as $key => $track) {
							$preview[] = $track->id;
							$tracklist[$track->name] = $track->external_urls->spotify;
						}
						
						$item->tracklist = $tracklist;
						$item->preview = implode(',', $preview);
						
						// Get album release date
						$item->date = $album->release_date;
						
						
						// Artists name
						$artists = $album->artists;
						
						$item->category_alias = '';
						$item->category = '';
						
						// Tags used for filter layout
						foreach ($artists as $key => $artist) {
							$item->artist[$artist->name] = $artist->external_urls->spotify;
							$item->category_alias .= $zen->clean($artist->name). ' ';
							$item->category .= $artist->name . ' ';
						}
						
					}
					
					
					// Tags that should be nulled
					$item->featured = null;
					$item->catlink = "";
					$item->newlink = 0;
					$item->video =false;
					$item->video_url="";
					$item->authorLink=false;
					$item->avatar=false;
					$item->tagblock=false;
					$item->rating="";
					
					// Increment the count
					$i++;
					
					// Add all items to an array
					$items[] = $item;
				}
	
				// Return the items
				return $items;
			}
		}
		
		
		// Check to see if cached response exists
		/* gets the contents of a file if it exists, otherwise grabs and caches */
		private static function get_content($file,$url,$hours = 24,$zen) {
			//vars
			$current_time = time(); 
			$expire_time = $hours * 60 * 60; 
			
			$file_time = $current_time;
			
			if(file_exists($file)) {
			
				$file_time = filemtime($file);
			
				// check to see if file is older than the cache time
				if($current_time - $expire_time > $file_time) {
					// Get the content
					$content = $zen->get_curl($url);
					// Write the cache file
					file_put_contents($file,$content);
					//$content = self::write_spotify($file, $url);
					$content = json_decode($content);
					return $content;
					
				} else {
					// File is still fresh so get the contents
					$content = file_get_contents($file);
					$content = json_decode($content);
					return $content;
				}
			}
			else {
				// File doesnt exist so lets create it
				//$content = self::write_spotify($file, $url);
				// Get the content
				$content = $zen->get_curl($url);
				// Write the cache file
				file_put_contents($file,$content);
				
				$content = json_decode($content);
				return $content;
			}
		}
		
		
		private static function write_spotify($file,$url) {
			// Get the content
			$content = $zen->get_curl($url);
			
			// Write the cache file
			file_put_contents($file,$content);
			
			return $content;
		}
	
	}